==> eam-wshub-proxyclient-11.4-0-sources.jar: org/xmlsoap/schemas/ws/_2002/_04/secext/ObjectFactory.java <==

package org.xmlsoap.schemas.ws._2002._04.secext;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.xmlsoap.schemas.ws._2002._04.secext package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.xmlsoap.schemas.ws._2002._04.secext
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BinarySecurityToken }
     * 
     */
    public BinarySecurityToken createBinarySecurityToken() {
        return new BinarySecurityToken();
    }

    /**
     * Create an instance of {@link SecurityTokenReference }
     * 
     */
    public SecurityTokenReference createSecurityTokenReference() {
        return new SecurityTokenReference();
    }

    /**
     * Create an instance of {@link Reference }
     * 
     */
    public Reference createReference() {
        return new Reference();
    }

    /**
     * Create an instance of {@link Username }
     * 
     */
    public Username createUsername() {
        return new Username();
    }

    /**
     * Create an instance of {@link UsernameToken }
     * 
     */
    public UsernameToken createUsernameToken() {
        return new UsernameToken();
    }

    /**
     * Create an instance of {@link Password }
     * 
     */
    public Password createPassword() {
        return new Password();
    }

    /**
     * Create an instance of {@link Security }
     * 
     */
    public Security createSecurity() {
        return new Security();
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: org/xmlsoap/schemas/ws/_2002/_04/secext/ObjectFactory.java <==

package org.xmlsoap.schemas.ws._2002._04.secext;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.xmlsoap.schemas.ws._2002._04.secext package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.xmlsoap.schemas.ws._2002._04.secext
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Security }
     * 
     * @return
     *     the new instance of {@link Security }
     */
    public Security createSecurity() {
        return new Security();
    }

    /**
     * Create an instance of {@link UsernameToken }
     * 
     * @return
     *     the new instance of {@link UsernameToken }
     */
    public UsernameToken createUsernameToken() {
        return new UsernameToken();
    }

    /**
     * Create an instance of {@link Username }
     * 
     * @return
     *     the new instance of {@link Username }
     */
    public Username createUsername() {
        return new Username();
    }

    /**
     * Create an instance of {@link Password }
     * 
     * @return
     *     the new instance of {@link Password }
     */
    public Password createPassword() {
        return new Password();
    }

    /**
     * Create an instance of {@link BinarySecurityToken }
     * 
     * @return
     *     the new instance of {@link BinarySecurityToken }
     */
    public BinarySecurityToken createBinarySecurityToken() {
        return new BinarySecurityToken();
    }

    /**
     * Create an instance of {@link SecurityTokenReference }
     * 
     * @return
     *     the new instance of {@link SecurityTokenReference }
     */
    public SecurityTokenReference createSecurityTokenReference() {
        return new SecurityTokenReference();
    }

    /**
     * Create an instance of {@link Reference }
     * 
     * @return
     *     the new instance of {@link Reference }
     */
    public Reference createReference() {
        return new Reference();
    }

}
